@@ -21,15 +21,22 @@ module Gitsh
     end
 
     def _prior
-      repo.revision_name('@{-1}')
+      repo.revision_name('@{-1}') ||
+        raise(UnsetVariableError, 'No prior branch')
     end
 
     def _merge_base
-      repo.merge_base('HEAD', 'MERGE_HEAD')
+      repo.merge_base('HEAD', 'MERGE_HEAD').tap do |merge_base|
+        if merge_base.empty?
+          raise UnsetVariableError, 'No merge in progress'
+        end
+      end
     end
 
     def _rebase_base
-      read_file(['rebase-apply', 'onto']) || read_file(['rebase-merge', 'onto'])
+      read_file(['rebase-apply', 'onto']) ||
+        read_file(['rebase-merge', 'onto']) ||
+        raise(UnsetVariableError, 'No rebase in progress')
     end
 
     def read_file(path_components)
